*** AIDS Chicago Project in Care Demo Program Showing Chained Imputations Method *** 
 
*** Analyst: Tor Neilands ***
** October 11, 2012 **
** 17jan2013 correct plottype in -midiagplots visit6m- to 'histogram'

version 12.1

*** Read Data File ***

use AFC_demo_compressed_V2.dta, clear

// Drop unneeded variables to keep data set as compact as possible 
// This may not be a significant drag on computing time/speed for
// ordinary analyses with the original data set, but inefficiences 
// can be multiplied M times for M imputed data sets, so we'll 
// be extra careful here to remove unneeded variables at the getgo. 

drop gender gh2 sixmovisit

*** Describe the variables in the data set ***

describe, short

*** Show amount of missing data and patterns *** 

summ gay_harr race sex_orn age ///
	 visit6m hiv_meds hiv_mnths ///
	 stigma hetrosxism dss1 dss2 ///
	 med_worries soc_supp

// Age and gender have no missing data, but gender has no variance (all male sample) 

misstable summarize gay_harr race sex_orn age ///
	 visit6m hiv_meds hiv_mnths ///
	 stigma hetrosxism dss1 dss2 ///
	 med_worries soc_supp
	 
// Internalized heterosexism and six month doctor visit have the most missing data

misstable patterns gay_harr race sex_orn age ///
	 visit6m hiv_meds hiv_mnths ///
	 stigma hetrosxism dss1 dss2 ///
	 med_worries soc_supp, freq
	 
// Patterns output shows only 340 (60%) cases with complete data 

// Suggests we should do at least 40 imputations b/c 40% of the data are missing
// following the recent rule of thumb recommended by Paul Allison on his 
// Statistical Horizons blog. We will do 5 here for illustrative purposes. 

*** Perform the typical analyses with listwise deletion first *** 

* Unadjusted regressions for gay-related harrassment *

// HC3 (heteroskedastic-consistent robust standard errors - type 3) 
// included as a just-in-case to guard against possible assumption
// violations

regress gay_harr age, hc3 

regress gay_harr i.visit6m, hc3

// Age is significantly negatively related to harassment; doctor visits
// were unrelated to harassment

tab race
regress gay_harr i.race, hc3
test 2.race 3.race 4.race

tab sex_orn
regress gay_harr i.sex_orn, hc3
test 2.sex_orn 3.sex_orn 4.sex_orn

// There are significant overall differences in means for both
// race and sexual orientation. Pairwise comparisons showed that
// Blacks and Hispanics reported less harassment relative to whites.
// Straight-identified reported less harassment than gay-identified.

* Adjusted regression for gay-related harrassment with listwise deletion * 

regress gay_harr i.race i.sex_orn age ///
			visit6m hiv_meds hiv_mnths ///
			stigma hetrosxism dss1 dss2 ///
			med_worries soc_supp, hc3
test 2.race 3.race 4.race
test 2.sex_orn 3.sex_orn 4.sex_orn

// No significant overall effects. Only Black vs. white in pairwise 
// comparisons is statitically significantly lower (p = .03)

*** -mi set- and -mi register- data and variables, respectively *** 

mi set flong 
mi register imputed gay_harr hetrosxism ///
			race sex_orn  ///
		    visit6m hiv_meds hiv_mnths ///
			stigma dss1 dss2 ///
			med_worries soc_supp 
mi register regular age
mi describe 

*** Do dry run to make sure prediction equations are as desired *** 

mi impute chained (regress) gay_harr hetrosxism ///
		  med_worries soc_supp hiv_mnths ///
		  stigma (ologit) dss1 dss2 (mlogit) race ///
		  sex_orn (logit) hiv_meds visit6m = age, dryrun 

*** Next, generate trace plot to evaluate number of burn-in iterations *** 

preserve

mi impute chained (regress) gay_harr hetrosxism ///
		  med_worries soc_supp hiv_mnths ///
		  stigma (ologit) dss1 dss2 (mlogit) race ///
		  sex_orn (logit) hiv_meds visit6m = age, /// 
		  rseed(1359) augment chainonly burnin(100) savetrace(impstats, replace)
		  
// Note: This takes a while to run - about a minute on my CAPS desktop
// Note: Need to use -augment- option due to zero cell in intersection of 
//       sexual orientation and race/ethnicity 

// Code based on Stata documentation examples for diagnosing convergence in
// -mi impute chained-. Here we generate and display trace plots for the 
// variables with the most missing data, internalized heterosexism and
// six month doctor visit. In a real appliccation, to be thorough we 
// would generate trace plots for any variable with missing data.

use impstats, clear
describe 
tsset iter
tsline hetrosxism_mean, name(gr1, replace) nodraw
tsline hetrosxism_sd, name(gr2, replace) nodraw
tsline visit6m_mean, name(gr3, replace) nodraw
tsline visit6m_sd, name(gr4, replace) nodraw
graph combine gr1 gr2 gr3 gr4, title(Trace plots of summaries of imputed values) row(2) name(TracePlot_1, replace)
graph save TracePlot_1, replace
graph export TracePlot_1.pdf, replace

restore 

// The above code is out of the Stata 12 -mi- documentation, p. 151
// The code below is from p. 152 of the same manual. It generates three imputed datasets
// generated by separate chains and then overlays trace plots of the three chains

preserve

quietly mi impute chained (regress) gay_harr hetrosxism ///
		  med_worries soc_supp hiv_mnths ///
		  stigma (ologit) dss1 dss2 (mlogit) race ///
		  sex_orn (logit) hiv_meds visit6m = age, /// 
		  rseed(1359) augment add(3) burnin(100) savetrace(impstats2, replace) 

use impstats2, clear
reshape wide *mean *sd, i(iter) j(m)
tsset iter
tsline hetrosxism_mean1 hetrosxism_mean2 hetrosxism_mean3, ///
ytitle(Mean of Internalized Heterosexism) yline(25.24) nodraw  name(gr1x, replace) ///
legend(rows(1) label(1 "Chain 1") label(2 "Chain 2") label(3 "Chain 3"))
tsline visit6m_mean1 visit6m_mean2 visit6m_mean3, ytitle(Mean of Six Month Doctor Visit) yline(25.24) ///
legend(rows(1) label(1 "Chain 1") label(2 "Chain 2") label(3 "Chain 3")) nodraw name(gr2x, replace)
graph combine gr1x gr2x, title(Overlaid trace plots of summaries of imputed values) row(2) name(TracePlot_2, replace)
graph save TracePlot_2, replace
graph export TracePlot_2.pdf, replace

restore 

*** Now, do the real deal: generate imputations *** 

// Alter value in -add- option to increase number of imputations from 5
// to a more robust number, say, 40 or 50 if this were real analysis
		  
mi impute chained (regress) gay_harr hetrosxism ///
		  med_worries soc_supp hiv_mnths ///
		  stigma (ologit) dss1 dss2 (mlogit) race ///
		  sex_orn (logit) hiv_meds visit6m = age, ///
		  add(5) rseed(1359) augment 

*** Run diagnostic plots on the two variables with the most missing data ***

*** Note "plottype(cumul) combine" for hetrosxism
midiagplots hetrosxism, ks m(1/5) plottype(cumul) combine 
graph save MIDiagPlot_1, replace
graph use MIDiagPlot_1, name(MIDiagPlot_1, replace)
graph export MIDiagPlot_1.pdf, replace

*** Note "plottype(histogram) separate" for hetrosxism
midiagplots visit6m, m(1/5) plottype(histogram) combine xlab(0 1)
graph save MIDiagPlot_2, replace
graph use MIDiagPlot_2, name(MIDiagPlot_2, replace)
graph export MIDiagPlot_2.pdf, replace

*** Save imputed data sets so you can use them again later without re-generating them *** 

save "AFC_demo_imputed_data.dta", replace

*** Call MI imputed data sets *** 

use "AFC_demo_imputed_data.dta", clear

* Unadjusted regressions for gay-related harrassment *

mi estimate: regress gay_harr age, hc3 

mi estimate: regress gay_harr i.visit6m, hc3

mi estimate: regress gay_harr i.race, hc3
mi test 2.race 3.race 4.race

mi estimate: regress gay_harr i.sex_orn, hc3
mi test 2.sex_orn 3.sex_orn 4.sex_orn

* Adjusted regression for gay-related harrassment * 

mi estimate: regress gay_harr i.race i.sex_orn age ///
			visit6m hiv_meds hiv_mnths ///
			stigma hetrosxism dss1 dss2 ///
			med_worries soc_supp, hc3
mi test 2.race 3.race 4.race
mi test 2.sex_orn 3.sex_orn 4.sex_orn

// Compare with listwise and FIML results. How do the results compare? 

exit





